@@ -7,10 +7,11 @@ CREATE TABLE tags (
 CREATE USER alice NOLOGIN;
 GRANT ALL ON TABLE tags TO alice;
 
-INSERT INTO tags VALUES (1, 'nonexistent', 'PostgreSQL');
-INSERT INTO tags VALUES (2, 'alice', 'Groonga');
-INSERT INTO tags VALUES (3, 'alice', 'groonga');
-INSERT INTO tags VALUES (4, 'alice', 'PGroonga');
+INSERT INTO tags VALUES (1, 'nonexistent', 'GROONGA');
+INSERT INTO tags VALUES (2, 'nonexistent', 'PostgreSQL');
+INSERT INTO tags VALUES (3, 'alice', 'Groonga');
+INSERT INTO tags VALUES (4, 'alice', 'groonga');
+INSERT INTO tags VALUES (5, 'alice', 'PGroonga');
 
 ALTER TABLE tags ENABLE ROW LEVEL SECURITY;
 CREATE POLICY tags_myself ON tags USING (user_name = current_user);
@@ -27,14 +28,14 @@ SET SESSION AUTHORIZATION alice;
 EXPLAIN (COSTS OFF)
 SELECT name
   FROM tags
- WHERE name &= ('groonga', NULL, 'pgrn_index')::pgroonga_full_text_search_condition
+ WHERE name &= pgroonga_condition('groonga', index_name => 'pgrn_index')
  ORDER BY id
-\g |sed -r -e "s/\(CURRENT_USER\)::text/CURRENT_USER/g"
+\g |sed -r -e "s/('.+'|ROW.+)::pgroonga/pgroonga/g" -e "s/\(CURRENT_USER\)::text/CURRENT_USER/g"
 \pset format aligned
 
 SELECT name
   FROM tags
- WHERE name &= ('groonga', NULL, 'pgrn_index')::pgroonga_full_text_search_condition
+ WHERE name &= pgroonga_condition('groonga', index_name => 'pgrn_index')
  ORDER BY id;
 RESET SESSION AUTHORIZATION;
 
